@@ -98,7 +98,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	gchar *station = NULL, *station_link;
 	VoiceInfo *voinfo = gnome_voice_file_loader (voinfo, voice_filename);
 	*path = champlain_path_layer_new ();
-	champlain_path_layer_set_stroke_color(path, &city_color);
+	// champlain_path_layer_set_stroke_color(path, &city_color);
 	layer = champlain_marker_layer_new_full (CHAMPLAIN_SELECTION_SINGLE);
 	layer_actor = CLUTTER_ACTOR (layer);	
 	while (voinfo != NULL) {
@@ -606,11 +606,12 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	g_date_strftime (timebuffer, sizeof (timebuffer), "%s", &d);
 	session = soup_session_sync_new ();
 	voice_pointer = fopen(filename_voice, "w");
+	fprintf(voice_pointer, "<?xml version=\"1.0\"?>\n");	
 	fprintf(voice_pointer, "<voice version='%s'>\n", VERSION);
 	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/GNOME.ogg'>\n",
 		g_get_real_name(),
 		g_get_host_name());
-	fprintf(voice_pointer, "    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
+	fprintf(voice_pointer, "    <location lat='%9.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
 	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice");
 	fprintf(voice_pointer, "  </station>\n");
 	fprintf(voice_pointer, "</voice>\n");
@@ -695,7 +696,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 1.2.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 1.5.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Voicegram", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -719,7 +720,7 @@ main (gint argc, gchar **argv)
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 1.2.0");
+	context = g_option_context_new ("- Voice 1.5.0");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -732,10 +733,10 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.2.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 1.5.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 1.2.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 1.5.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Voicegram:"));
 	title_entry = gtk_entry_new();
@@ -813,7 +814,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 1.2.0",
+				 GST_TAG_COMMENT, "Voice 1.5.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
